---
description: "Samples to accompany the official Microsoft Blazor documentation."
page_type: sample
languages:
- csharp
- cshtml
name: "Blazor sample applications"
products:
- aspnet-core
- blazor
urlFragment: "blazor-samples"
---
# Samples to accompany the official Microsoft Blazor documentation

Samples in this repository accompany the [official Microsoft Blazor documentation](https://docs.microsoft.com/aspnet/core/blazor/).

To obtain a local copy of the sample apps in this repository, use ***either*** of the following approaches:

* [Fork this repository](https://docs.github.com/get-started/quickstart/fork-a-repo) and [clone it](https://docs.github.com/repositories/creating-and-managing-repositories/cloning-a-repository) to your local system.
* Select the **Code** button. Select **Download ZIP** to save the repository locally. Extract the saved Zip archive (`.zip`) to access the sample apps.

## Sample app article links (latest release)

* General Blazor samples referenced by the full Blazor documentation set (`BlazorSample_BlazorWebApp`/`BlazorSample_BlazorWebAssembly`)

* .NET MAUI Blazor Hybrid app with a Blazor Web App and a shared UI RCL (`MauiBlazorWeb`)<br>[Build a .NET MAUI Blazor Hybrid app with a Blazor Web App](https://learn.microsoft.com/aspnet/core/blazor/hybrid/tutorials/maui-blazor-web-app)

* Blazor with SignalR (`BlazorSignalRApp`)<br>[Use ASP.NET Core SignalR with Blazor](https://learn.microsoft.com/aspnet/core/blazor/tutorials/signalr-blazor)

* Blazor Web App movie database app tutorial (`BlazorWebAppMovies`)<br>[Build a Blazor movie database app](https://learn.microsoft.com/aspnet/core/blazor/tutorials/movie-database-app)

* Blazor Web App with EF Core (`BlazorWebAppEFCore`)<br>[ASP.NET Core Blazor with Entity Framework Core (EF Core)](https://learn.microsoft.com/aspnet/core/blazor/blazor-ef-core)

* Blazor Web App with Microsoft Entra ID (`BlazorWebAppEntra`)<br>[Secure an ASP.NET Core Blazor Web App with Microsoft Entra ID](https://learn.microsoft.com/aspnet/core/blazor/security/blazor-web-app-with-entra)

* Blazor Web App with OIDC and Aspire (`BlazorWebAppOidcBff`/`BlazorWebAppOidc`)<br>[Secure an ASP.NET Core Blazor Web App with OpenID Connect (OIDC)](https://learn.microsoft.com/aspnet/core/blazor/security/blazor-web-app-with-oidc)

* Call a web API (`BlazorWebAppCallWebApi`/`BlazorWebAssemblyCallWebApi`/`BlazorWebAppCallWebApi_Weather`)<br>[Call a web API from ASP.NET Core Blazor](https://learn.microsoft.com/aspnet/core/blazor/call-web-api)

* Blazor WebAssembly scopes-enabled logging (`BlazorWebAssemblyScopesLogger`)<br>[ASP.NET Core Blazor logging: Client-side log scopes](https://learn.microsoft.com/aspnet/core/blazor/fundamentals/logging#client-side-log-scopes)

* Blazor WebAssembly with ASP.NET Core Identity (`BlazorWebAssemblyStandaloneWithIdentity`)<br>[Blazor WebAssembly with ASP.NET Core Identity](https://learn.microsoft.com/aspnet/core/blazor/security/webassembly/standalone-with-identity)

* Blazor WebAssembly with app roles, built-in Azure Administrator roles, and Azure security groups (`BlazorWebAssemblyEntraGroupsAndRoles`)<br>[Microsoft Entra (ME-ID) groups, Administrator Roles, and App Roles](https://learn.microsoft.com/aspnet/core/blazor/security/webassembly/microsoft-entra-id-groups-and-roles)

* WebAssembly Browser App import-export interop (`WASMBroswerAppImportExportInterop`)<br>[JavaScript [JSImport]/[JSExport] interop with a WebAssembly Browser App project](https://learn.microsoft.com/aspnet/core/client-side/dotnet-interop/wasm-browser-app)

## Snippet sample apps for article code examples

**WARNING**: Always follow an article's security guidance when implementing sample code.

Prior to the release of .NET 8, snippet sample apps for Blazor Server and Blazor WebAssembly provide the code examples that appear in Blazor articles. Many of the components in the snippet sample apps compile and run if copied to a local test app. However, the entire snippet sample apps aren't meant to be runnable demonstration sample apps, and not all of the components are completely functional. The purpose of the snippet sample apps prior to .NET 8's release is merely to supply code examples to documentation.

For the release of .NET 8 (and later releases), the sample apps for Blazor Web App and Blazor WebAssembly both supply snippets to articles and are fully working demonstration sample apps.

Blazor snippet sample apps

* Blazor Web App (.NET 8 or later)
* Blazor Server (.NET 7.0 or earlier)
* Blazor WebAssembly

## Community help and support

For more information, see the *Support requests* section in the [Blazor *Fundamentals* overview article](https://docs.microsoft.com/aspnet/core/blazor/fundamentals/#support-requests).
